#include <cuda_runtime.h>
浏览源代码.
|
| bool | apollo::planning::InitialCuda () |
| |
| __global__ void | apollo::planning::fill_lower_left_gpu (int *iRow, int *jCol, unsigned int *rind_L, unsigned int *cind_L, const int nnz_L) |
| |
| template<typename T > |
| __global__ void | apollo::planning::data_transfer_gpu (T *dst, const T *src, const int size) |
| |
| bool | apollo::planning::fill_lower_left (int *iRow, int *jCol, unsigned int *rind_L, unsigned int *cind_L, const int nnz_L) |
| |
| template<typename T > |
| bool | apollo::planning::data_transfer (T *dst, const T *src, const int size) |
| |
◆ BLOCK_1
◆ CUDA_CHECK
| #define CUDA_CHECK |
( |
|
call | ) |
|
值: { \
const cudaError_t error = call; \
if (error != cudaSuccess) { \
printf("Error: %s:%d, ", __FILE__, __LINE__); \
printf("code: %d, reasone: %s\n", error, cudaGetErrorString(error)); \
return false; \
} \
}
在文件 planning_block.h 第 49 行定义.
50 { \
51 const cudaError_t error = call; \
52 if (error != cudaSuccess) { \
53 printf("Error: %s:%d, ", __FILE__, __LINE__); \
54 printf("code: %d, reasone: %s\n", error, cudaGetErrorString(error)); \
55 return false; \
56 } \
57 }
◆ DATA_TRANSFER_INST
| #define DATA_TRANSFER_INST |
( |
|
type | ) |
|
值:
bool, data_transfer(type *dst, const type *src, const int size))
#define TEMPLATE_ROUTINE_INSTANCE(ret, routine)
在文件 planning_block.h 第 45 行定义.
◆ TEMPLATE_ROUTINE_INSTANCE
| #define TEMPLATE_ROUTINE_INSTANCE |
( |
|
ret, |
|
|
|
routine |
|
) |
| template ret routine |